declare type Encoding = 'ascii' | 'utf8' | 'utf-8' | 'utf16le' | 'ucs2' | 'ucs-2' | 'base64' | 'base64url' | 'latin1' | 'binary' | 'hex';
/**
 * Converts an Uint8Array to an encoded string.
 * Following encodings can be used:
 * 'ascii' | 'utf8' | 'utf-8' | 'utf16le' | 'ucs2' | 'ucs-2' | 'base64' | 'base64url' | 'latin1' | 'binary' | 'hex'
 * @param uint8Array the Uint8Array to convert
 * @param encoding the enoding to use
 * @returns the encoded string
 */
declare const toString: (uint8Array: Uint8Array, encoding: Encoding) => string;
/**
 * Converts an encoded string to an Uint8Array.
 * Following encodings can be used:
 * 'ascii' | 'utf8' | 'utf-8' | 'utf16le' | 'ucs2' | 'ucs-2' | 'base64' | 'base64url' | 'latin1' | 'binary' | 'hex'
 * @param string the encoded string
 * @param encoding the enoding to use
 * @returns the decoded Uint8Array
 */
declare const fromString: (string: string, encoding: Encoding) => Uint8Array;
export { Encoding, fromString, toString };
