declare const unauthenticInputException: Error;
declare const invalidWrapInputException: Error;
declare const invalidUnwrapInputException: Error;
/**
 * Wrapps (respectively encrypts) a key with a kek (key-encryption key), using aes-key-wrap.
 * Key and kek, both must be 16, 24, or 32 bytes long
 * @param key the key to wrap (Unit8Array)
 * @param kek the kek (Unit8Array)
 * @throws an Error if key and/or kek length is invalid
 * @returns the wrapped key (Unit8Array)
 */
declare const wrapKey: (key: Uint8Array, kek: Uint8Array) => Uint8Array;
/**
 * Unwrapps (respectively decrypts) a wrapped key with a kek (key-encryption key), using aes-key-unwrap.
 * Kek must be 16, 24, or 32 bytes long, wrapped key must be 8 bytes longer.
 * @param wrappedKey the wrapped key to unwrap (Unit8Array)
 * @param kek the kek (Unit8Array)
 * @throws an Error if wrappedKey and/or kek length is invalid
 * @throws an Error on unauthentic data (Message: 'Unauthentic data. Wrong kek?')
 * @returns the unwrapped key (Unit8Array)
 */
declare const unwrapKey: (wrappedKey: Uint8Array, kek: Uint8Array) => Uint8Array;
export { invalidUnwrapInputException, invalidWrapInputException, unauthenticInputException, unwrapKey, wrapKey };
