"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapKeyToString = exports.unwrapKeyFromString = void 0;
const converting_1 = require("./converting");
const wrapping_1 = require("./wrapping");
/**
 * Wraps an key with a kek, using aes-key-wrap and converts the wrapped key to an encoded string
 * @param key the key to wrap (UintArray)
 * @param kek the kek (Uint8Array)
 * @param encoding the encoding to use
 * @throws an Error if key and/or kek length is invalid
 * @returns the encoded wrapped key
 * @see {@link toString} for available encodings
 */
const wrapKeyToString = function (key, kek, encoding) {
    return (0, converting_1.toString)((0, wrapping_1.wrapKey)(key, kek), encoding);
};
exports.wrapKeyToString = wrapKeyToString;
/**
 * Converts an encoded string to an Uint8Array as wrapped key and unwraps it with a kek, using aes-key-wrap
 * @param encodedWrappedKey the encoded wrapped key to unwrap
 * @param kek the kek (Uint8Array)
 * @param encoding the encoding to use
 * @throws an Error if wrappedKey and/or kek length is invalid
 * @throws an Error on unauthentic data (Message: 'Unauthentic data. Wrong kek?')
 * @returns the unwrapped key (Uint8Array)
 * @see {@link fromString} for available encodings
 */
const unwrapKeyFromString = function (encodedWrappedKey, kek, encoding) {
    return (0, wrapping_1.unwrapKey)((0, converting_1.fromString)(encodedWrappedKey, encoding), kek);
};
exports.unwrapKeyFromString = unwrapKeyFromString;
