"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assertthat_1 = require("assertthat");
const converting_1 = require("../../lib/converting");
suite('converting', () => {
    const uint8Array = new Uint8Array(Buffer.from('abc+/123', 'base64'));
    const convertings = [
        {
            encoding: 'base64',
            string: 'abc+/123'
        },
        {
            encoding: 'base64url',
            string: 'abc-_123'
        },
        {
            encoding: 'hex',
            string: Buffer.from('abc+/123', 'base64').toString('hex')
        },
        {
            encoding: 'binary',
            string: Buffer.from('abc+/123', 'base64').toString('binary')
        }
    ];
    suite('to String', () => {
        for (const { encoding, string } of convertings) {
            test(`returns ${string} on ${encoding} encoding.`, async () => {
                const actualString = (0, converting_1.toString)(uint8Array, encoding);
                assertthat_1.assert.that(actualString).is.equalTo(string);
            });
        }
    });
    suite('from String', () => {
        for (const { encoding, string } of convertings) {
            test(`returns original uint8Array on ${encoding} encoding.`, async () => {
                const actualUint8Array = (0, converting_1.fromString)(string, encoding);
                assertthat_1.assert.that(actualUint8Array).is.equalTo(uint8Array);
            });
        }
    });
});
